# Joystick （操纵杆）插件

JOYSTICK插件处理来自操纵杆设备的输入，包括轨迹球和（电子游戏风格的）游戏板。在PyGame的joystick模块中，joystick插件允许使用带有按钮、轴、轨迹球和顶部切换键的操纵杆。

## 选项和反应变量

Joystick插件的运行方式与键盘反应项类似。有关详细信息，请参阅关于键盘反应项(KEYBOARD_RESPONSE-item)的帮助或访问：

- <http://osdoc.cogsci.nl/3.2/manual/response/keyboard/>

## 按键名称

Depending on the kind of joystick or gamepad you use, a different number of buttons, axes, tracksballs, and hats are available. Please make sure you know which button corresponds to which button number (same goes for axes, hats and trackballs).
根据你使用的操纵杆或游戏板的类型，可以使用不同数量的按钮、轴、轨迹球和顶部切换键。请确保你知道哪个按键对应哪个按键编号（同样适用于轴、顶部切换键和轨迹球）。

更多信息请参考:

- <http://osdoc.cogsci.nl/3.2/manual/response/joystick/>
